@@ -118,8 +118,9 @@ const struct option long_options[] =
 {"tos",        required_argument, NULL, 'S'},
 {"ttl",        required_argument, NULL, 'T'},
 {"single_udp",       no_argument, NULL, 'U'},
-{"ipv6_domian",      no_argument, NULL, 'V'},
+{"ipv6_domain",      no_argument, NULL, 'V'},
 {"suggest_win_size", no_argument, NULL, 'W'},
+{"linux-congestion", required_argument, NULL, 'Z'},
 {0, 0, 0, 0}
 };
 
@@ -162,12 +163,13 @@ const struct option env_options[] =
 {"IPERF_SINGLE_UDP",       no_argument, NULL, 'U'},
 {"IPERF_IPV6_DOMAIN",      no_argument, NULL, 'V'},
 {"IPERF_SUGGEST_WIN_SIZE", required_argument, NULL, 'W'},
+{"IPERF_CONGESTION_CONTROL",  required_argument, NULL, 'Z'},
 {0, 0, 0, 0}
 };
 
 #define SHORT_OPTIONS()
 
-const char short_options[] = "1b:c:df:hi:l:mn:o:p:rst:uvw:x:y:B:CDF:IL:M:NP:RS:T:UVW";
+const char short_options[] = "1b:c:df:hi:l:mn:o:p:rst:uvw:x:y:B:CDF:IL:M:NP:RS:T:UVWZ:";
 
 /* -------------------------------------------------------------------
  * defaults
@@ -373,12 +375,8 @@ void Settings_Interpret( char option, const char *optarg, thread_Settings *mExtS
             break;
 
         case 'h': // print help and exit
-#ifndef WIN32
-            fprintf( stderr, usage_long );
-#else
             fprintf(stderr, usage_long1);
             fprintf(stderr, usage_long2);
-#endif
             exit(1);
             break;
 
@@ -664,6 +662,16 @@ void Settings_Interpret( char option, const char *optarg, thread_Settings *mExtS
             fprintf( stderr, "The -W option is not available in this release\n");
             break;
 
+        case 'Z':
+#ifdef TCP_CONGESTION
+	    setCongestionControl( mExtSettings );
+	    mExtSettings->mCongestion = new char[strlen(optarg)+1];
+	    strcpy( mExtSettings->mCongestion, optarg);
+#else
+            fprintf( stderr, "The -Z option is not available on this operating system\n");
+#endif
+	    break;
+
         default: // ignore unknown
             break;
     }
